{{- swot_analysis.company_listing.display_name -}}
{{- " (" -}}{{- swot_analysis.company_listing.country -}}{{- ") | " -}}
{%- set unique_tickers = swot_analysis.company_listing.tickers | map(attribute='ticker') | unique | list -%}
{%- for ticker in unique_tickers -%}
    {{- ticker -}}
    {%- if not loop.last %}, {% endif -%}
{%- endfor -%}
{{- " | Earnings: " -}}
{{- "✅" if swot_analysis.use_earnings_call else "❌" -}}
{%- if swot_analysis.use_earnings_call and swot_analysis.earnings_call_start_date -%}
    {{- " (from " -}}{{- swot_analysis.earnings_call_start_date -}}{{- ")" -}}
{%- endif -%}
{{- " | Web: " -}}
{{- "✅" if swot_analysis.use_web_sources else "❌" -}}