{% if executive_summary is not none and executive_summary |length > 0 %}

{{ executive_summary }}


{% endif %}

{% if strengths |length > 0 %}
# Strengths

{% for section in strengths %}
## {{ section.h2 }}

{% for entry in section.entries %}
- **{{ entry.preview }}** {{ entry.content }}
{% endfor %}

{% endfor %}
---

{% endif %}
{% if weaknesses |length > 0 %}
# Weaknesses

{% for section in weaknesses %}
## {{ section.h2 }}

{% for entry in section.entries %}
- **{{ entry.preview }}** {{ entry.content }}
{% endfor %}

{% endfor %}
---

{% endif %}
{% if opportunities |length > 0 %}
# Opportunities

{% for section in opportunities %}
## {{ section.h2 }}

{% for entry in section.entries %}
- **{{ entry.preview }}** {{ entry.content }}
{% endfor %}

{% endfor %}
---

{% endif %}
{% if threats |length > 0 %}
# Threats

{% for section in threats %}
## {{ section.h2 }}

{% for entry in section.entries %}
- **{{ entry.preview }}** {{ entry.content }}
{% endfor %}

{% endfor %}
---

{% endif %}